pype32.datatypes.String

Package pype32 :: Module datatypes :: Class String |
[hide private]
[frames] | no frames]

# Class String

source code

    object --+
             |
            String

Known Subclasses:
  - AlignedString

String object.

Instance Methods | [hide private]
__init__(self, value=`'````'`, shouldPack=True) x.__init__(...) initializes x; see help(type(x)) for signature | source code
__str__(self) str(x) | source code
__len__(self) | source code
sizeof(self) Returns the size of the string. | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, value=`'````'`, shouldPack=True) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Parameters: `value` (str) - the string to be built. `shouldPack` (bool) - (Optional) If set to c{True}, the object will be packed. If set to `False`, the object won't be packed. Overrides: object.__init__ To Do: Add a UnicodeString class.

### __str__(self) (Informal representation operator) | source code
str(x) Overrides: object.__str__ (inherited documentation)